@@ -9,6 +9,7 @@
 char *parser_parlist(register Parser *pp, HANDLER_SET_ELEMENTS newSet)
 {
     register char *str = 0;
+    register StackValue stValue;
 
     if (lexer_lex(&pp->d_lexer) != TOKEN_OPENPAR)
         if (message_show(MSG_CRIT))
@@ -21,14 +22,16 @@ char *parser_parlist(register Parser *pp, HANDLER_SET_ELEMENTS newSet)
     pp->d_parlist_filename = new_str(message_filename());
 
     lexer_unget_matched(&pp->d_lexer);
-    stack_push(&pp->d_paren_st, (void *)pp->d_paren);
+
+    stValue.u_size_t = pp->d_paren;
+    stack_push(&pp->d_paren_st, stValue);
     pp->d_paren = 0;
 
     p_begin_nested(pp, newSet);
     p_parse(pp);
     str = p_end_nested(pp, newSet);
 
-    pp->d_paren = (unsigned)stack_tos(&pp->d_paren_st);
+    pp->d_paren = stack_tos(&pp->d_paren_st)->u_size_t;
     stack_pop(&pp->d_paren_st);
 
     return str;
