@@ -4,11 +4,10 @@ char *p_end_nested(register Parser *pp, HANDLER_SET_ELEMENTS newSet)
 {
     register char *text = 0;
                                             /* restore the handler set      */
-    pp->d_handler = (bool (**)(struct Parser *))stack_tos(&pp->d_handler_st);
+    pp->d_handler = stack_tos(&pp->d_handler_st)->u_Pfun1p;
     stack_pop(&pp->d_handler_st);
-
-    pp->d_insert =                          /* restore the inserter         */
-        (void (*)(struct Parser *, char const *))stack_tos(&pp->d_insert_st);
+                                            /* restore the inserter         */
+    pp->d_insert = stack_tos(&pp->d_insert_st)->u_Pfun2p;
     stack_pop(&pp->d_insert_st);
 
     switch (newSet)
@@ -17,7 +16,7 @@ char *p_end_nested(register Parser *pp, HANDLER_SET_ELEMENTS newSet)
         case DEFAULT_SET:
                                             /* obtain the nested text       */
             text = string_release(pp->d_string_ptr);
-            pp->d_string_ptr = (String *)stack_tos(&pp->d_string_st);
+            pp->d_string_ptr = stack_tos(&pp->d_string_st)->u_Stringp;
             stack_pop(&pp->d_string_st);
         break;
 
