@@ -2,9 +2,9 @@
 
 void s_init(register String *str, register char const *txt)
 {
-    unsigned newlength;
+    size_t newlength;
 
-    if (txt && *txt)
+    if (*txt)
         newlength = strlen(txt);
     else
     {
