@@ -3,22 +3,23 @@
 void gram_DEFINEMACRO()
 {
     register char *name;
-    int nargs;
+    int args;
 
     parser_push_fun("DEFINEMACRO");
 
     name  = parser_name_parlist(&parser,  true);
 
-    if (parser_number_parlist(&parser, &nargs, true) == SUCCESS)
+    if (parser_number_parlist(&parser, &args, true) == SUCCESS)
     {
         char *def   = parser_parlist(&parser, COLLECT_SET);
+        size_t nargs = args;
 
-        if ((unsigned)nargs > 9 + 26 + 26)          /* 1-9, a-z, A-Z    */
+        if (nargs > 9 + 26 + 26)          /* 1-9, a-z, A-Z    */
         {
             if (message_show(MSG_ERR))
                 message(
-                    "DEFINEMACRO: max. %u arguments supported, not %d",
-                    9 + 26 + 26, nargs);
+                    "DEFINEMACRO: max. %d arguments supported, not %d",
+                    9 + 26 + 26, args);
         }
         else if
         (
